<?php defined('BASEPATH') or exit('No direct scripts access allowed.');

if(!function_exists('daysago'))
{
  function daysago($datetime, $full = false)
  {
    $now = new DateTime;
    $ago = new DateTime($datetime);
    $diff = $now->diff($ago);
    
    $diff->w = floor($diff->d / 7);
    $diff->d -= $diff->w * 7;
    
    $string = array(
      'y' => 'year',
      'm' => 'month',
      'w' => 'week',
      'd' => 'day',
      'h' => 'hour',
      'i' => 'minute',
      's' => 'second',
    );
    foreach ($string as $k => &$v) {
      if ($diff->$k) {
        $v = $diff->$k . ' ' . $v . ($diff->$k > 1 ? 's' : '');
      } else {
        unset($string[$k]);
      }
    }
    
    if (!$full) $string = array_slice($string, 0, 1);
    return $string ? implode(', ', $string) . ' ago' : 'just now';
  }
  
  function cleanVal($value = '', $option = null)
  {
    $value = trim($value);
    $value = strtr($value,array_flip(get_html_translation_table(HTML_ENTITIES)));
    $value = strip_tags($value);
    // $value = mysqli_real_escape_string(get_mysqli(), $value);
    $value = htmlspecialchars($value);
    if($option != null)
    {
      if ($option == 'int') {
        $value = filter_var($value, FILTER_SANITIZE_NUMBER_INT);
      }
      else if($option == 'str')
      {
        $value = filter_var($value, FILTER_SANITIZE_STRING);
      }
      else if($option == 'email')
      {
        $value = filter_var($value, FILTER_SANITIZE_EMAIL);
      }
      
    }
    return $value;
  }
  
  function debug($array, $exit = false)
  {
    echo '<pre>';
    print_r($array);
    echo '</pre>';
    if($exit)
    {
      exit;
    }
  }
  
  function getBrowser($user_agent)
  {
    // Make case insensitive.
    $t = strtolower($user_agent);
    
    // If the string *starts* with the string, strpos returns 0 (i.e., FALSE). Do a ghetto hack and start with a space.
    // "[strpos()] may return Boolean FALSE, but may also return a non-Boolean value which evaluates to FALSE."
    //     http://php.net/manual/en/function.strpos.php
    $t = " " . $t;
    
    // Humans / Regular Users
    if     (strpos($t, 'opera'     ) || strpos($t, 'opr/')     ) return '<i class="fab fa-opera"></i> Opera'            ;
    elseif (strpos($t, 'edge'      )                           ) return '<i class="fab fa-edge"></i> Edge'             ;
    elseif (strpos($t, 'chrome'    )                           ) return '<i class="fab fa-chrome"></i> Chrome'           ;
    elseif (strpos($t, 'safari'    )                           ) return '<i class="fab fa-safari"></i> Safari'           ;
    elseif (strpos($t, 'firefox'   )                           ) return '<i class="fab fa-firefox"></i> Firefox'          ;
    elseif (strpos($t, 'msie'      ) || strpos($t, 'trident/7')) return '<i class="fab fa-internet-explorer"></i> Internet Explorer';
    
    // Search Engines
    elseif (strpos($t, 'google'    )                           ) return '[Bot] Googlebot'   ;
    elseif (strpos($t, 'bing'      )                           ) return '[Bot] Bingbot'     ;
    elseif (strpos($t, 'slurp'     )                           ) return '[Bot] Yahoo! Slurp';
    elseif (strpos($t, 'duckduckgo')                           ) return '[Bot] DuckDuckBot' ;
    elseif (strpos($t, 'baidu'     )                           ) return '[Bot] Baidu'       ;
    elseif (strpos($t, 'yandex'    )                           ) return '[Bot] Yandex'      ;
    elseif (strpos($t, 'sogou'     )                           ) return '[Bot] Sogou'       ;
    elseif (strpos($t, 'exabot'    )                           ) return '[Bot] Exabot'      ;
    elseif (strpos($t, 'msn'       )                           ) return '[Bot] MSN'         ;
    
    // Common Tools and Bots
    elseif (strpos($t, 'mj12bot'   )                           ) return '[Bot] Majestic'     ;
    elseif (strpos($t, 'ahrefs'    )                           ) return '[Bot] Ahrefs'       ;
    elseif (strpos($t, 'semrush'   )                           ) return '[Bot] SEMRush'      ;
    elseif (strpos($t, 'rogerbot'  ) || strpos($t, 'dotbot')   ) return '[Bot] Moz or OpenSiteExplorer';
    elseif (strpos($t, 'frog'      ) || strpos($t, 'screaming')) return '[Bot] Screaming Frog';
    
    // Miscellaneous
    elseif (strpos($t, 'facebook'  )                           ) return '[Bot] Facebook'     ;
    elseif (strpos($t, 'pinterest' )                           ) return '[Bot] Pinterest'    ;
    
    // Check for strings commonly used in bot user agents
    elseif (strpos($t, 'crawler' ) || strpos($t, 'api'    ) ||
    strpos($t, 'spider'  ) || strpos($t, 'http'   ) ||
    strpos($t, 'bot'     ) || strpos($t, 'archive') ||
    strpos($t, 'info'    ) || strpos($t, 'data'   )    ) return '[Bot] Other'   ;
    
    return 'Other (Unknown)';
  }
  
  function getOS($user_agent)
  {
    $os_platform    =   '<i class="far fa-question-circle"></i> Unknown';
    $os_array       =   array(
      '/windows nt 10/i'      =>  '<i class="fab fa-windows"></i> Windows 10',
      '/windows nt 6.3/i'     =>  '<i class="fab fa-windows"></i> Windows 8.1',
      '/windows nt 6.2/i'     =>  '<i class="fab fa-windows"></i> Windows 8',
      '/windows nt 6.1/i'     =>  '<i class="fab fa-windows"></i> Windows 7',
      '/windows nt 6.0/i'     =>  '<i class="fab fa-windows"></i> Windows Vista',
      '/windows nt 5.2/i'     =>  '<i class="fab fa-windows"></i> Windows Server 2003/XP x64',
      '/windows nt 5.1/i'     =>  '<i class="fab fa-windows"></i> Windows XP',
      '/windows xp/i'         =>  '<i class="fab fa-windows"></i> Windows XP',
      '/windows nt 5.0/i'     =>  '<i class="fab fa-windows"></i> Windows 2000',
      '/windows me/i'         =>  '<i class="fab fa-windows"></i> Windows ME',
      '/win98/i'              =>  '<i class="fab fa-windows"></i> Windows 98',
      '/win95/i'              =>  '<i class="fab fa-windows"></i> Windows 95',
      '/win16/i'              =>  '<i class="fab fa-windows"></i> Windows 3.11',
      '/macintosh|mac os x/i' =>  '<i class="fab fa-apple"></i> Mac OS X',
      '/mac_powerpc/i'        =>  '<i class="fab fa-apple"></i> Mac OS 9',
      '/linux/i'              =>  '<i class="fab fa-linux"></i> Linux',
      '/ubuntu/i'             =>  '<i class="fab fa-ubuntu"></i> Ubuntu',
      '/iphone/i'             =>  '<i class="fas fa-mobile-alt"></i> iPhone',
      '/ipod/i'               =>  '<i class="fas fa-compact-disc"></i> iPod',
      '/ipad/i'               =>  '<i class="fas fa-tablet-alt"></i> iPad',
      '/android/i'            =>  '<i class="fab fa-android"></i> Android',
      '/blackberry/i'         =>  '<i class="fab fa-blackberry"></i> BlackBerry',
      '/webos/i'              =>  '<i class="fas fa-mobile"></i> Mobile'
    );
    foreach ($os_array as $regex => $value)
    {
      if (preg_match($regex, $user_agent))
      {
        $os_platform    =   $value;
      }
    }
    return $os_platform;
  }
  
  
  function getTitle($url = null) {
    // Extract HTML using curl
    $ch = curl_init();
    
    curl_setopt($ch, CURLOPT_HEADER, 0);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
    
    $data = curl_exec($ch);
    curl_close($ch);
    
    // Load HTML to DOM Object
    $dom = new DOMDocument();
    @$dom->loadHTML($data);
    
    // Parse DOM to get Title
    $nodes = $dom->getElementsByTagName('title');
    $title = $nodes->item(0)->nodeValue;
    return $title;
  }
  
  function newID($num,$len,$str=null){
    $num = str_pad($num, $len, '0', STR_PAD_LEFT); 
    return strtoupper($str).$num;
  }
  
  function getDashedText($string) {
    // Replace all spaces and special characters with a dash
    $string = preg_replace('/[^A-Za-z0-9]/', '-', $string);
    return $string;
  }
  
  function k2m($kb) {
    $mb = $kb / 1024;
    return round($mb, 2).' MB';
  }
  
  function d2n($str,$opt='caps'){
    // Dashed to text
    if (!empty($opt) && $opt === 'caps') {
      return ucwords(str_replace('-',' ',$str));
    } else {
      return str_replace('-',' ',$str);
    }
  }
  
  function get_file_type($file_path) {
    
    $file_info = pathinfo($file_path);
    $extension = $file_info['extension'];
    
    $extension_file_types = array(
      'txt' => 'Text file',
      'html' => 'HTML file',
      'css' => 'CSS file',
      'js' => 'JavaScript file',
      'csv' => 'CSV file',
      'jpeg' => 'JPEG image',
      'jpg' => 'JPEG image',
      'png' => 'PNG image',
      'gif' => 'GIF image',
      'bmp' => 'BMP image',
      'webp' => 'WebP image',
      'pdf' => 'PDF document',
      'doc' => 'Word document',
      'xls' => 'Excel spreadsheet',
      'ppt' => 'PowerPoint presentation',
      'docx' => 'Word document',
      'xlsx' => 'Excel spreadsheet',
      'pptx' => 'PowerPoint presentation',
      'zip' => 'ZIP archive',
      'mp3' => 'MP3 audio',
      'ogg' => 'OGG audio',
      'wav' => 'WAV audio',
      'mp4' => 'MP4 video',
      'webm' => 'WebM video',
      'ogv' => 'OGG video'
    );
    
    $file_type = isset($extension_file_types[$extension]) ? $extension_file_types[$extension] : 'Unknown';
    return $file_type;
  }
  
  function formatSizeUnits($bytes) {
    if ($bytes >= 1073741824) {
      $bytes = number_format($bytes / 1073741824, 2) . ' GB';
    } elseif ($bytes >= 1048576) {
      $bytes = number_format($bytes / 1048576, 2) . ' MB';
    } elseif ($bytes >= 1024) {
      $bytes = number_format($bytes / 1024, 2) . ' KB';
    } elseif ($bytes > 1) {
      $bytes = $bytes . ' bytes';
    } elseif ($bytes == 1) {
      $bytes = $bytes . ' byte';
    } else {
      $bytes = '0 bytes';
    }
    return $bytes;
  }
  
  function rrmdir($dir) {
    if (is_dir($dir)) {
      $objects = scandir($dir);
      foreach ($objects as $object) {
        if ($object != "." && $object != "..") {
          if (is_dir($dir."/".$object)) {
            rrmdir($dir."/".$object);
          } else {
            unlink($dir."/".$object);
          }
        }
      }
      rmdir($dir);
      return true;
    }
  }
  
  
}

?>
