<?php
class Crud extends CI_Model
{
	public function getDataAll($table, $orderByCol = null, $order = null, $limit = null)
	{
		$this->db->from($table);
		if (isset($orderByCol) && isset($order)) {
			$this->db->order_by($orderByCol, $order);
		}
		if ($limit != null) {
			$this->db->limit($limit);
		}
		$query = $this->db->get();
		$result = $query->result();
		return $result;
	}
	public function getUniqueAll($table, $colName = null)
	{
		$this->db->select('*');
		$this->db->group_by($colName);
		$this->db->from($table);
		$query = $this->db->get();
		return $query->result();
	}
	public function getDataSingle($table, $id, $idname = null, $all = null, $pageName = null, $location_city = null)
	{
		$this->db->from($table);
		if ($pageName != null) {
			$this->db->where('pageName', $pageName);
		}
		if ($idname != null) {
			$this->db->where($idname, $id);
		} else {
			$this->db->where('id', $id);
		}
		if ($location_city != null) {
			$this->db->like('product_delivery_locations', $location_city, 'both');
		}
		$query = $this->db->get();
		if ($all == true) {
			$result = $query->result();
		} else {
			$result = $query->row();
		}
		return $result;
	}
	public function getCountriesByContinent($continent = null)
	{
		$this->db->select('name');
		$this->db->from('countries');
		$this->db->where('region', $continent);
		$this->db->order_by('name', 'asc');
		$query = $this->db->get();
		$result = $query->result();
		return $result;
	}
	public function getPolicies($country = null, $covered_type = null)
	{
		// Start the query with the 'policies' table
		$this->db->from('policies');
		
		// Add the country condition with LIKE
		if ($country !== null) {
			// $this->db->where('country', $country);
			$this->db->like('country', $country, 'both');
		}
		
		// Add the covered_type condition
		if ($covered_type !== null) {
			$ct = explode(',', $covered_type);
			
			// Add the facilities condition with AND (combining all LIKE conditions)
			$this->db->group_start(); // Start grouping for AND logic
			foreach ($ct as $ctVal) {
				$this->db->or_where('facilities', $ctVal);
				// $this->db->or_like('facilities', $ctVal, 'both');
			}
			$this->db->group_end(); // End grouping
		}
		
		// Order by id, descending
		$this->db->order_by('id', 'desc');
		
		// Execute the query and return the result
		$query = $this->db->get();
		return $query->result();
	}
	
	public function getSetting($settingName)
	{
		$this->db->from('settings');
		$this->db->where('name', $settingName);
		$query = $this->db->get();
		return $query->row()->value;
	}
	public function save($table, $data, $getId)
	{
		if ($this->db->insert($table, $data)) {
			if ($getId == true) {
				return $this->db->insert_id();
			} else if ($getId == false) {
				return true;
			}
		} else {
			return false;
		}
	}
	public function update($table, $idkey, $id, $data)
	{
		$this->db->where($idkey, $id);
		if ($this->db->update($table, $data)) {
			return true;
		} else {
			return false;
		}
	}
	public function delete($table, $idkey, $id)
	{
		$from_tbl = $table;
		$to_tbl = $table.'_deleted';
		$row = $this->db->get_where($from_tbl, array($idkey => $id))->row_array();
		// if ($this->db->insert($to_tbl, $row) && $this->db->delete($from_tbl, array($idkey => $id))) {
		if ($this->db->delete($from_tbl, array($idkey => $id))) {
			return true;
		} else {
			return false;
		}
	}
	public function save_upload($title, $image)
	{
		$data = array(
			'title'     => $title,
			'file'      => $image
		);
		$result = $this->db->insert('media', $data);
		return $result;
	}
	public function getCountAll($table)
	{
		return $this->db->count_all($table);
	}
	public function getCountAllUnique($table, $colName)
	{
		$this->db->group_by($colName);
		$this->db->from($table);
		return $this->db->count_all_results();
	}
	public function getMatchedCount($table, $query, $colName)
	{
		// $this->db->group_by($colName);
		$this->db->from($table);
		$this->db->like($colName, $query, 'both');
		return $this->db->count_all_results();
	}
	public function getCount($table, $colName, $colVal)
	{
		return $this->db->where($colName, $colVal)->count_all_results($table);
	}
	public function verify_user($username, $password, $remember=false)
	{
		$this->db->where('username', $username);
		$this->db->where('password', $password);
		$query = $this->db->get('su');
		if ($query->num_rows() == 1)
		{
			if ($remember == true) {
				$cookie = array(
					'name'          => 'rm',
					'value'         => hashed($username),
					'expire'        => 86500,
					'domain'        => 'oneandallservices.in',
					'path'          => '/',
					'prefix'        => 'chatbot_',
					'secure'        => TRUE,
					'samesite'      => 'Strict'
				);
				$this->input->set_cookie($cookie);
			}
			return true;
		} else {
			return false;
		}
	}
	public function verify_student($username, $password)
	{
		$this->db->where('sid', $username);
		$this->db->where('password', $password);
		$query = $this->db->get('students');
		if ($query->num_rows() > 0)
		{
			return true;
		} else {
			return false;
		}
	}
	public function verify_expert($username, $password)
	{
		$this->db->where('eid', $username);
		$this->db->where('password', $password);
		$query = $this->db->get('experts');
		if ($query->num_rows() > 0)
		{
			return true;
		} else {
			return false;
		}
	}
	public function verify_employee($username, $password)
	{
		$this->db->where('eid', $username);
		$this->db->where('password', $password);
		$query = $this->db->get('employees');
		if ($query->num_rows() > 0)
		{
			return true;
		} else {
			return false;
		}
	}
	public function verify_logged_in_user($username, $password)
	{
		$this->db->where('eid', $username);
		$this->db->where('password', $password);
		$query = $this->db->get('users');
		if ($query->num_rows() > 0)
		{
			return true;
		} else {
			return false;
		}
	}
	public function getLeadsForEmployeeByStatus($uid=null,$status=null,$oid=null,$limit = null)
	{
		$this->db->from('user_leads');
		if ($uid != null) {
			$this->db->where('uid', $uid);
		}
		if ($status != null) {
			$this->db->where('opportunity', $status);
		}
		if ($oid != null) {
			$this->db->where('oid', $oid);
		}
		$this->db->order_by('id', 'DESC');
		if ($limit != null) {
			$this->db->limit($limit);
		}
		$query = $this->db->get();
		$result = $query->result();
		return $result;
	}
	public function move_row($id, $from_tbl, $to_tbl) 
	{
		// Retrieve the row to be moved
		$row = $this->db->get_where($from_tbl, array('id' => $id))->row_array();
		// Insert the row into the destination table
		$this->db->insert($to_tbl, $row);
		// Delete the row from the original table (optional)
		$this->db->delete($from_tbl, array('id' => $id));
	}
	public function getAllFoldersByUser($eid,$limit=null)
	{
		$this->db->from('folders');
		$this->db->where('eid', $eid);
		$this->db->order_by('id', 'DESC');
		if ($limit != null) {
			$this->db->limit($limit);
		}
		$query = $this->db->get();
		return $query->result();
	}
	public function getAllFoldersFilesByUser($eid,$fid,$udate)
	{
		$this->db->from('files');
		$this->db->where('eid', $eid);
		$this->db->where('fid', $fid);
		$this->db->where('udate', date('Y-m-d',strtotime($udate)));
		$this->db->order_by('id', 'DESC');
		$query = $this->db->get();
		return $query->result();
	}
	public function getAllFoldersFilesDatesByUser($eid,$fid)
	{
		$this->db->from('files');
		$this->db->where('eid', $eid);
		$this->db->where('fid', $fid);
		$this->db->order_by('udate', 'DESC');
		$this->db->group_by('DATE(udate)');
		$query = $this->db->get();
		return $query->result();
	}
	public function getAllFoldersFilesBySelectedUser($eid,$fid)
	{
		$this->db->from('files');
		$this->db->where('eid', $eid);
		$this->db->where('fid', $fid);
		$this->db->order_by('udate', 'DESC');
		// $this->db->group_by('DATE(udate)');
		$query = $this->db->get();
		return $query->result();
	}
	public function getAllFilesByUser($eid)
	{
		$this->db->from('files');
		$this->db->where('eid', $eid);
		// $this->db->where('fid', $fid);
		$this->db->order_by('udate', 'DESC');
		// $this->db->group_by('DATE(udate)');
		$query = $this->db->get();
		return $query->result();
	}
	public function getAllUsers($type = null, $singleRow = null)
	{
		$this->db->from('users');
		if ($type != null && $type != 'both') {
			$this->db->where('type', $type);
		}
		$this->db->order_by('id', 'DESC');
		$query = $this->db->get();
		if (!empty($singleRow) && $singleRow == true) {
			$result = $query->row();
		} else {
			$result = $query->result();
		}
		return $result;
	}
	public function getAllSupportRequest($uid = null)
	{
		$this->db->from('support');
		if ($uid != null) {
			$this->db->where('uid', $uid);
		}
		$this->db->order_by('id', 'DESC');
		$query = $this->db->get();
		$result = $query->result();
		return $result;
	}
	public function deleteFF($path) {
		unlink($path);
		return true;
	}
	public function getById($table, $id) {
		return $this->db->get_where($table, ['name' => $id])->row();
	}
	public function getDataWhere($table, $where, $order_by, $order) {
		return $this->db->order_by($order_by, $order)->get_where($table, $where)->result();
	}
	public function getAllInsurere()
	{
		$this->db->from('insurer');
		$this->db->where('insurer_logo !=', null);
		$this->db->where('insurer_name !=', null);
		$this->db->where('currency !=', null);
		$this->db->order_by('id', 'desc');
		$query = $this->db->get();
		$result = $query->result();
		return $result;
	}
	public function delete_file($file_path) {
		// Check if the file exists
		if (file_exists($file_path)) {
			// Attempt to delete the file
			if (unlink($file_path)) {
				// File deleted successfully
				return true;
			} else {
				// Failed to delete the file
				return false;
			}
		} else {
			// File does not exist
			return false;
		}
	}
	public function getDeductibleFiles($iid = null)
	{
		$this->db->from('deductible_files');
		$this->db->where('iid', $iid);
		$this->db->order_by('id', 'ASC');
		$query = $this->db->get();
		$result = $query->result();
		return $result;
	}
	public function getDeductibleFilesCounts($iid = null)
	{
		$this->db->where('iid', $iid);
		$query = $this->db->get('deductible_files');
		return $query->num_rows() ?? (int)'0';
	}
	public function getDeductibleRates($iid = null, $deductible_files_id = null)
	{
		$this->db->from('deductible_rates');
		$this->db->where('iid', $iid);
		$this->db->where('deductible_files_id', $deductible_files_id);
		$this->db->order_by('id', 'ASC');
		$query = $this->db->get();
		$result = $query->result();
		return $result;
	}
	public function getDeductibleFileAgeWiseData($iid = null, $deductible_files_id = null, $maxage = null)
	{
		$this->db->from('deductible_file_data');
		$this->db->where('iid', $iid);
		$this->db->where('deductible_files_id', $deductible_files_id);
		$this->db->where('age', $maxage);
		$query = $this->db->get();
		$result = $query->row();
		return $result;
	}
	public function getDeductibleFileAgeWiseDataAll($iid = null, $deductible_files_id = null)
	{
		$this->db->from('deductible_file_data');
		$this->db->where('iid', $iid);
		$this->db->where('deductible_files_id', $deductible_files_id);
		$query = $this->db->get();
		$result = $query->result();
		return $result;
	}
	public function getDeductibleFilesRow($iid = null, $fid = null)
	{
		$this->db->from('deductible_files');
		$this->db->where('iid', $iid);
		$this->db->where('id', $fid);
		$query = $this->db->get();
		$result = $query->row();
		return $result;
	}
	public function loadCountries()
	{
		$this->db->select('name');
		$this->db->order_by('name', 'ASC');
		$query = $this->db->get('countries');
		$result = $query->result();
		return $result;
	}
	public function update_insurer($iid, $data) {
		$this->db->where('id', $iid);
		return $this->db->update('insurer', $data);
	}
	public function saveDeductibleFile($data) {
		$this->db->insert('deductible_files', $data);
		return $this->db->insert_id(); // Return the inserted file ID
	}
	
	public function saveDeductibleRate($data) {
		$this->db->insert('deductible_rates', $data);
	}
	
	public function saveDeductibleFileData($data) {
		$this->db->insert('deductible_file_data', $data);
	}
	public function get_all_insurers() {
		$this->db->select('*');
		$query = $this->db->get('insurer');
		return $query->result_array(); // Return as an array
	}
	public function get_all_policies() {
		$this->db->select('*');
		$query = $this->db->get('policies');
		return $query->result_array(); // Return as an array
	}
	public function get_all_requests() {
		$this->db->select('*');
		$query = $this->db->get('requests');
		return $query->result_array(); // Return as an array
	}
}
