async function fetchDataById(id) {
  try {
    let response = await fetch(`https://dp-client.com/insurance/get-policy-data-api/${id}`); // Your API endpoint
      let data = await response.json();
      if (response.ok) {
        console.log("Fetched Data:", data); // Log fetched data
        return data;
      } else {
        return { error: data.message || 'Unknown error occurred' };
      }
    } catch (error) {
      console.error("Error fetching data:", error);
      return { error: "Failed to fetch data" };
    }
  }
  async function showModal(modalSelector, id, pid = null, policy_name = null, insurer_name = null) {
    if (pid != '' && policy_name != '' && insurer_name != '') {    
      $('#pid').val(pid);
      $('#policy_name').val(policy_name);
      $('#insurer_name').val(insurer_name);
    }
    // Show loader before starting data fetch
    var loader = document.getElementById('loader');
    loader.style.display = 'block';
    // Fetch data based on the ID
    let result = await fetchDataById(id);
    // Hide loader after fetching data
    loader.style.display = 'none';
    if (result.error) {
      swal({
        title: "Error Occured!",
        text: `Error: ${result.error}`,
        icon: "error",
        button: false,
        timer: 2500
      });
      console.log(`Error: ${result.error}`);
      return;
    }
    // Populate modal with fetched data
    populateModal(modalSelector, result);
    // Proceed to show modal if no error
    var modal = document.querySelector(modalSelector);
    if (!modal) {
      console.error("Modal not found. Please check your selector.");
      return;
    }
    modal.classList.add("cst-show-modal");
    document.body.classList.add("body-overflow");
    // Close modal when pressing the ESC key
    document.addEventListener('keydown', function(event) {
      if (event.key === "Escape") {
        hideModal(modalSelector);
      }
    });
  }
  // function populateModal(modalSelector, data) {
  //   // Loop through data and populate corresponding elements in the modal
  //   Object.keys(data).forEach(function(key) {
  //     let element = document.querySelector(`${modalSelector} .${key}_value`);
  //     if (element) {
  //       if (element.tagName === 'IMG') {
  //         // If the element is an image, set the src attribute
  //         element.src = data[key];
  //       } else if (element.tagName === 'INPUT') {
  //         // If the element is an input, set the value attribute
  //         element.value = data[key];
  //       } else {
  //         // For other elements, just set the text content
  //         element.textContent = data[key];
  //       }
  //     }
  //   });
  // }
  function populateModal(modalSelector, data) {
    // Loop through data and populate corresponding elements in the modal
    Object.keys(data).forEach(function(key) {
      let element = document.querySelector(`${modalSelector} .${key}_value`);
      if (element) {
        if (element.tagName === 'IMG') {
          // If the element is an image, set the src attribute
          element.src = data[key];
        } else if (element.tagName === 'INPUT') {
          // If the element is an input, set the value attribute
          element.value = data[key];
        } else {
          // For other elements, just set the text content
          element.textContent = data[key];
        }
      }
    });
    // Handle showing/hiding based on the facilities value
    const facilities = data.facilities;
    // Hide all classes first
    document.querySelectorAll('.inpatientClass, .outpatientClass, .dentalClass, .maternityClass, .maternityWitoutDentalClass ').forEach(el => el.style.display = 'none');
    // Show specific classes based on the facilities value
    if (facilities === "Inpatient") {
      document.querySelectorAll('.inpatientClass').forEach(el => el.style.display = 'block');
    } else if (facilities === "Outpatient") {
      document.querySelectorAll('.inpatientClass, .outpatientClass').forEach(el => el.style.display = 'block');
    } else if (facilities === "Dental") {
      // No classes should be displayed for Dental, hence nothing needs to be done here
      document.querySelectorAll('.inpatientClass, .outpatientClass, .dentalClass').forEach(el => el.style.display = 'block');
    } else if (facilities === "Maternity") {
      document.querySelectorAll('.inpatientClass, .outpatientClass, .dentalClass, .maternityClass').forEach(el => el.style.display = 'block');
    }
    else if (facilities === "MaternityWitoutDental") {
      document.querySelectorAll('.inpatientClass, .outpatientClass, .maternityWitoutDentalClass').forEach(el => el.style.display = 'block');
    }
  }
  function hideModal(modalSelector) {
    var modal = document.querySelector(modalSelector);
    if (!modal) {
      console.error("Modal not found. Please check your selector.");
      return;
    }
    modal.classList.remove("cst-show-modal");
    document.body.classList.remove("body-overflow");
  }
  function setupModals() {
    // Close modal when clicking the close button
    document.querySelectorAll('.cst-close-button').forEach(function(button) {
      button.addEventListener('click', function() {
        hideModal('.' + button.closest('.cst-modal').classList[1]);
      });
    });
    // Close modal when clicking outside the modal content (overlay area)
    window.addEventListener('click', function(event) {
      if (event.target.classList.contains('cst-modal')) {
        hideModal('.' + event.target.classList[1]);
      }
    });
  }
  // Initialize modals
  setupModals();
  document.addEventListener('DOMContentLoaded', function () {
    const loader = document.getElementById('loaderPM');
    const cardContainer = document.getElementById('quote-count-list');
    const cards = Array.from(cardContainer.getElementsByClassName('quote-listv1'));
    const sortMinRadio = document.getElementById('minimum-limit');
    const sortMaxRadio = document.getElementById('maximum-limit');
    // Function to sort cards
    function sortCards(order) {
      // Show loader while sorting
      loader.style.display = 'flex';
      // Sort the cards
      const sortedCards = cards.sort((a, b) => {
        const valA = parseInt(a.getAttribute('data-val'), 10);
        const valB = parseInt(b.getAttribute('data-val'), 10);
        return order === 'asc' ? valA - valB : valB - valA;
      });
      // Clear container and append sorted cards with animation
      cardContainer.innerHTML = ''; // Clear the container first
      sortedCards.forEach(card => {
        card.style.opacity = 0; // Hide cards initially
        cardContainer.appendChild(card); // Append the sorted cards
      });
      // Apply smooth transition and hide loader
      sortedCards.forEach((card, index) => {
        setTimeout(() => {
          card.style.opacity = 1; // Gradually show cards
          if (index === sortedCards.length - 1) {
            // Hide the loader after the last card is fully visible
            loader.style.display = 'none';
          }
        }, index * 100); // delay for smooth transition
      });
    }
    // Perform default sort in ascending order on page load
    sortCards('asc');
    sortMinRadio.checked = true;
    // Event listeners for sorting options
    sortMinRadio.addEventListener('change', function () {
      if (this.checked) {
        sortCards('asc');
      }
    });
    sortMaxRadio.addEventListener('change', function () {
      if (this.checked) {
        sortCards('desc');
      }
    });
  });